@@ -3,6 +3,7 @@
 # --------------------------------------------------
 
 # Python libs
+import os
 import textwrap
 import string
 import math
@@ -550,7 +551,7 @@ class RawTextRfcWriter(BaseRfcWriter):
                     cityline.append(region.text)
                 code = postal.find('code')
                 if code is not None and code.text:
-                    if len(cityline) > 0: cityline.append(' ');
+                    if len(cityline) > 0: cityline.append('  ');
                     cityline.append(code.text)
                 if len(cityline) > 0:
                     lines.append(''.join(cityline))
@@ -849,4 +850,4 @@ class RawTextRfcWriter(BaseRfcWriter):
         """ Writes the buffer to the specified file """
         for line in self.output:
             file.write(line)
-            file.write('\r\n')
+            file.write(os.linesep)
